@@ -1,8 +1,10 @@
 package App::CharmKit::Command::test;
-$App::CharmKit::Command::test::VERSION = '0.015';
+$App::CharmKit::Command::test::VERSION = '0.016';
 # ABSTRACT: Test your charm project
 
 
+use strict;
+use warnings;
 use parent 'App::CharmKit::Role::Pack';
 use App::CharmKit -command;
 
@@ -39,7 +41,7 @@ App::CharmKit::Command::test - Test your charm project
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
